@@ -8,5 +8,5 @@
 #' @export
 
 get_info <- function(verbose = FALSE) {
-  req(type = "entes", query = NULL, verbose = verbose)
-}
\ No newline at end of file
+  request(type = "entes", query = NULL, verbose = verbose)
+}
